@@ -199,6 +199,7 @@ _ARGS_BY_FILEFORMAT = {
     'png': [],
     'svg': ['-tsvg'],
     'txt': ['-ttxt'],
+    'latex': ['-tlatex:nopreamble'],
 }
 
 
@@ -541,6 +542,7 @@ _KNOWN_LATEX_FORMATS = {
     'eps': ('eps', lambda self, refname, fname: (refname, fname)),
     'pdf': ('eps', _convert_eps_to_pdf),
     'png': ('png', lambda self, refname, fname: (refname, fname)),
+    'tikz': ('latex', lambda self, refname, fname: (refname, fname)),
 }
 
 
@@ -553,6 +555,37 @@ def _lookup_latex_format(fmt):
             % (', '.join(map(repr, _KNOWN_LATEX_FORMATS)), fmt))
 
 
+def _latex_adjustbox_options(self, node):
+    adjustbox_options = []
+    if 'width' in node:
+        if 'scale' in node:
+            w = self.latex_image_length(node['width'], node['scale'])
+        else:
+            w = self.latex_image_length(node['width'])
+        if w:
+            adjustbox_options.append('width=%s' % w)
+    if 'height' in node:
+        if 'scale' in node:
+            h = self.latex_image_length(node['height'], node['scale'])
+        else:
+            h = self.latex_image_length(node['height'])
+        if h:
+            adjustbox_options.append('height=%s' % h)
+    if 'scale' in node:
+        if not adjustbox_options:
+            adjustbox_options.append('scale=%s'
+                                     % (float(node['scale']) / 100.0))
+    return adjustbox_options
+
+
+def _latex_add_package(self, package):
+    # TODO: Currently modifying the preamble to add a package, there may be
+    # a cleaner solution
+    package = '\\usepackage{%s}' % (package,)
+    if package not in self.elements['preamble']:
+        self.elements['preamble'] += package + '\n'
+
+
 def latex_visit_plantuml(self, node):
     _render_batches_on_vist(self)
     if 'latex_format' in node:
@@ -569,12 +602,26 @@ def latex_visit_plantuml(self, node):
         logger.warning(str(err))
         raise nodes.SkipNode
 
-    # put node representing rendered image
-    img_node = nodes.image(uri=refname, **node.attributes)
-    img_node.delattr('uml')
-    if not img_node.hasattr('alt'):
-        img_node['alt'] = node['uml']
-    node.append(img_node)
+    if fmt == 'tikz':
+        _latex_add_package(self, 'tikz')
+
+        base, ext = os.path.splitext(refname)
+        input_macro = '\\input{{%s}%s}' % (base, ext)
+
+        adjustbox_options = _latex_adjustbox_options(self, node)
+        if adjustbox_options:
+            _latex_add_package(self, 'adjustbox')
+            options = ','.join(adjustbox_options)
+            self.body.append('\\adjustbox{%s}{%s}' % (options, input_macro))
+        else:
+            self.body.append(input_macro)
+    else:
+        # put node representing rendered image
+        img_node = nodes.image(uri=refname, **node.attributes)
+        img_node.delattr('uml')
+        if not img_node.hasattr('alt'):
+            img_node['alt'] = node['uml']
+        node.append(img_node)
 
 
 def latex_depart_plantuml(self, node):
